import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/components/senior_stateful_badge/model/SeniorStatefulBadgeState.model.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class StatefulBadgeExemple extends StatefulWidget {
  const StatefulBadgeExemple({Key? key}) : super(key: key);

  @override
  State<StatefulBadgeExemple> createState() => _StatefulBadgeExempleState();
}

class _StatefulBadgeExempleState extends State<StatefulBadgeExemple> {
  late String _resultado = '';
  void _onSelect(SeniorStatefulBadgeCallbackModel onSelectReturn) {
    setState(() {
      _resultado =
          'Retorno do click: Valor: ${onSelectReturn.value}, Selecionado: ${onSelectReturn.selectedState}';
    });
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Stateful Badge',
      child: ListView(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        children: [
          Panel(
            title: 'Pills',
            child: Wrap(
              spacing: SeniorSpacing.normal,
              runSpacing: SeniorSpacing.normal,
              children: [
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(
                        SeniorSpacing.xxsmall,
                      ),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.supportingColor,
                        fontColor: SeniorColors.pureWhite,
                        label: 'Supera as expectativas',
                        shape: SeniorBadgeShape.pill,
                        selectedBackgroundColor:
                            SeniorColors.supportingColor100,
                        selectedFontColor: SeniorColors.pureBlack,
                        selectedValue: 'Supera as expectativas',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.primaryColor400,
                        fontColor: SeniorColors.pureBlack,
                        label: 'Atende plenamente',
                        shape: SeniorBadgeShape.pill,
                        selectedBackgroundColor: SeniorColors.primaryColor100,
                        selectedFontColor: SeniorColors.primaryColor500,
                        selectedValue: 'Atende plenamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.manchesterColorBlue,
                        fontColor: SeniorColors.pureWhite,
                        label: 'Atende satisfatoriamente',
                        shape: SeniorBadgeShape.pill,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorBlue100,
                        selectedFontColor: SeniorColors.pureBlack,
                        selectedValue: 'Atende satisfatoriamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.manchesterColorYellow,
                        fontColor: SeniorColors.pureBlack,
                        label: 'Atende parcialmente',
                        shape: SeniorBadgeShape.pill,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorYellow100,
                        selectedFontColor:
                            SeniorColors.manchesterColorYellow500,
                        selectedValue: 'Atende parcialmente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.manchesterColorRed,
                        fontColor: SeniorColors.pureWhite,
                        label: 'Não atende',
                        shape: SeniorBadgeShape.pill,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorRed100,
                        selectedFontColor: SeniorColors.manchesterColorRed500,
                        selectedValue: 'Não atende',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                  ],
                ),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(
                        SeniorSpacing.xxsmall,
                      ),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.supportingColor,
                        disabledBackgroundColor: SeniorColors.secondaryColor400,
                        fontColor: SeniorColors.pureWhite,
                        disabledFontColor: SeniorColors.pureBlack,
                        label: 'Supera as expectativas',
                        shape: SeniorBadgeShape.pill,
                        disabled: true,
                        selectedBackgroundColor:
                            SeniorColors.supportingColor100,
                        selectedFontColor: SeniorColors.supportingColor500,
                        selectedValue: 'Supera as expectativas',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.primaryColor400,
                        disabledBackgroundColor: SeniorColors.secondaryColor400,
                        fontColor: SeniorColors.pureWhite,
                        disabledFontColor: SeniorColors.pureBlack,
                        label: 'Atende plenamente',
                        shape: SeniorBadgeShape.pill,
                        disabled: true,
                        selectedBackgroundColor: SeniorColors.primaryColor100,
                        selectedFontColor: SeniorColors.primaryColor500,
                        selectedValue: 'Atende plenamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.manchesterColorBlue,
                        disabledBackgroundColor: SeniorColors.secondaryColor400,
                        fontColor: SeniorColors.pureWhite,
                        disabledFontColor: SeniorColors.pureBlack,
                        label: 'Atende satisfatoriamente',
                        shape: SeniorBadgeShape.pill,
                        disabled: true,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorBlue100,
                        selectedFontColor: SeniorColors.manchesterColorBlue500,
                        selectedValue: 'Atende satisfatoriamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.manchesterColorYellow,
                        disabledBackgroundColor: SeniorColors.secondaryColor400,
                        fontColor: SeniorColors.pureBlack,
                        disabledFontColor: SeniorColors.pureBlack,
                        label: 'Atende parcialmente',
                        shape: SeniorBadgeShape.pill,
                        disabled: true,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorYellow100,
                        selectedFontColor:
                            SeniorColors.manchesterColorYellow500,
                        selectedValue: 'Atende parcialmente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge(
                        backgroundColor: SeniorColors.manchesterColorRed,
                        disabledBackgroundColor: SeniorColors.secondaryColor400,
                        fontColor: SeniorColors.pureWhite,
                        disabledFontColor: SeniorColors.pureBlack,
                        label: 'Não atende',
                        shape: SeniorBadgeShape.pill,
                        disabled: true,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorRed100,
                        selectedFontColor: SeniorColors.manchesterColorRed500,
                        selectedValue: 'Atende parcialmente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                  ],
                ),
              ],
            ),
          ),
          Panel(
            title: 'Chips',
            child: Wrap(
              spacing: SeniorSpacing.normal,
              runSpacing: SeniorSpacing.normal,
              children: [
                Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                  child: SeniorStatefulBadge(
                    backgroundColor: SeniorColors.manchesterColorGreen,
                    disabledBackgroundColor: SeniorColors.secondaryColor400,
                    fontColor: SeniorColors.pureWhite,
                    disabledFontColor: SeniorColors.pureBlack,
                    label: 'Enviado',
                    shape: SeniorBadgeShape.chip,
                    selectedBackgroundColor:
                        SeniorColors.manchesterColorGreen100,
                    selectedFontColor: SeniorColors.manchesterColorGreen500,
                    selectedValue: 'Enviado',
                    onSelect: (value) {
                      _onSelect(value);
                    },
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                  child: SeniorStatefulBadge(
                    backgroundColor: SeniorColors.manchesterColorBlue,
                    disabledBackgroundColor: SeniorColors.secondaryColor400,
                    fontColor: SeniorColors.pureWhite,
                    disabledFontColor: SeniorColors.pureBlack,
                    label: 'Atendido',
                    shape: SeniorBadgeShape.chip,
                    selectedBackgroundColor:
                        SeniorColors.manchesterColorBlue100,
                    selectedFontColor: SeniorColors.manchesterColorBlue500,
                    selectedValue: 'Atendido',
                    onSelect: (value) {
                      _onSelect(value);
                    },
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                  child: SeniorStatefulBadge(
                    backgroundColor: SeniorColors.manchesterColorYellow,
                    disabledBackgroundColor: SeniorColors.secondaryColor400,
                    fontColor: SeniorColors.pureBlack,
                    disabledFontColor: SeniorColors.pureBlack,
                    label: 'Aguardando',
                    shape: SeniorBadgeShape.chip,
                    selectedBackgroundColor:
                        SeniorColors.manchesterColorYellow100,
                    selectedFontColor: SeniorColors.manchesterColorYellow500,
                    selectedValue: 'Aguardando',
                    onSelect: (value) {
                      _onSelect(value);
                    },
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                  child: SeniorStatefulBadge(
                    backgroundColor: SeniorColors.manchesterColorGreen,
                    disabledBackgroundColor: SeniorColors.secondaryColor400,
                    fontColor: SeniorColors.pureWhite,
                    disabledFontColor: SeniorColors.pureBlack,
                    label: 'Enviado',
                    shape: SeniorBadgeShape.chip,
                    disabled: true,
                    selectedBackgroundColor:
                        SeniorColors.manchesterColorGreen100,
                    selectedFontColor: SeniorColors.manchesterColorGreen500,
                    selectedValue: 'Enviado',
                    onSelect: (value) {
                      _onSelect(value);
                    },
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                  child: SeniorStatefulBadge(
                    backgroundColor: SeniorColors.manchesterColorBlue,
                    disabledBackgroundColor: SeniorColors.secondaryColor400,
                    fontColor: SeniorColors.pureWhite,
                    disabledFontColor: SeniorColors.pureBlack,
                    label: 'Atendido',
                    shape: SeniorBadgeShape.chip,
                    disabled: true,
                    selectedBackgroundColor:
                        SeniorColors.manchesterColorBlue100,
                    selectedFontColor: SeniorColors.manchesterColorBlue500,
                    selectedValue: 'Atendido',
                    onSelect: (value) {
                      _onSelect(value);
                    },
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                  child: SeniorStatefulBadge(
                    backgroundColor: SeniorColors.manchesterColorYellow,
                    disabledBackgroundColor: SeniorColors.secondaryColor400,
                    fontColor: SeniorColors.pureBlack,
                    disabledFontColor: SeniorColors.pureBlack,
                    label: 'Aguardando',
                    shape: SeniorBadgeShape.chip,
                    disabled: true,
                    selectedBackgroundColor:
                        SeniorColors.manchesterColorYellow100,
                    selectedFontColor: SeniorColors.manchesterColorYellow500,
                    selectedValue: 'Aguardando',
                    onSelect: (value) {
                      _onSelect(value);
                    },
                  ),
                ),
              ],
            ),
          ),
          Panel(
            title: 'Pill - Icons',
            child: Wrap(
              spacing: SeniorSpacing.normal,
              runSpacing: SeniorSpacing.normal,
              children: [
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(
                        SeniorSpacing.xxsmall,
                      ),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.supportingColor,
                        fontColor: SeniorColors.pureWhite,
                        icon: FontAwesomeIcons.faceLaugh,
                        label: 'Supera as expectativas',
                        shape: SeniorBadgeShape.chip,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.supportingColor100,
                        selectedFontColor: SeniorColors.supportingColor500,
                        selectedValue: 'Supera as expectativas',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.primaryColor400,
                        fontColor: SeniorColors.pureBlack,
                        icon: FontAwesomeIcons.faceLaughWink,
                        label: 'Atende plenamente',
                        shape: SeniorBadgeShape.chip,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor: SeniorColors.primaryColor100,
                        selectedFontColor: SeniorColors.primaryColor500,
                        selectedValue: 'Atende plenamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.manchesterColorBlue,
                        fontColor: SeniorColors.pureWhite,
                        icon: FontAwesomeIcons.faceSmileWink,
                        label: 'Atende satisfatoriamente',
                        shape: SeniorBadgeShape.chip,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorBlue100,
                        selectedFontColor: SeniorColors.manchesterColorBlue500,
                        selectedValue: 'Atende satisfatoriamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.manchesterColorYellow,
                        fontColor: SeniorColors.pureBlack,
                        icon: FontAwesomeIcons.faceSmile,
                        label: 'Atende parcialmente',
                        shape: SeniorBadgeShape.chip,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorYellow100,
                        selectedFontColor:
                            SeniorColors.manchesterColorYellow500,
                        selectedValue: 'Atende parcialmente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.manchesterColorRed,
                        fontColor: SeniorColors.pureWhite,
                        icon: FontAwesomeIcons.faceMeh,
                        label: 'Não atende',
                        shape: SeniorBadgeShape.chip,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorRed100,
                        selectedFontColor: SeniorColors.manchesterColorRed500,
                        selectedValue: 'Não atende',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                  ],
                ),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(
                        SeniorSpacing.xxsmall,
                      ),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.supportingColor,
                        fontColor: SeniorColors.pureWhite,
                        icon: FontAwesomeIcons.faceLaugh,
                        label: 'Supera as expectativas',
                        shape: SeniorBadgeShape.pill,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.supportingColor100,
                        selectedFontColor: SeniorColors.supportingColor500,
                        selectedValue: 'Supera as expectativas',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.primaryColor400,
                        fontColor: SeniorColors.pureWhite,
                        icon: FontAwesomeIcons.faceLaughWink,
                        label: 'Atende plenamente',
                        shape: SeniorBadgeShape.pill,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor: SeniorColors.primaryColor100,
                        selectedFontColor: SeniorColors.primaryColor500,
                        selectedValue: 'Atende plenamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.manchesterColorBlue,
                        fontColor: SeniorColors.pureWhite,
                        icon: FontAwesomeIcons.faceSmileWink,
                        label: 'Atende satisfatoriamente',
                        shape: SeniorBadgeShape.pill,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorBlue100,
                        selectedFontColor: SeniorColors.manchesterColorBlue500,
                        selectedValue: 'Atende satisfatoriamente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.manchesterColorYellow,
                        fontColor: SeniorColors.pureBlack,
                        icon: FontAwesomeIcons.faceSmile,
                        label: 'Atende parcialmente',
                        shape: SeniorBadgeShape.pill,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorYellow100,
                        selectedFontColor:
                            SeniorColors.manchesterColorYellow500,
                        selectedValue: 'Atende parcialmente',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(SeniorSpacing.xxsmall),
                      child: SeniorStatefulBadge.icon(
                        backgroundColor: SeniorColors.manchesterColorRed,
                        fontColor: SeniorColors.pureWhite,
                        label: 'Não atende',
                        shape: SeniorBadgeShape.pill,
                        icon: FontAwesomeIcons.faceMeh,
                        selectedIcon: FontAwesomeIcons.faceDizzy,
                        selectedBackgroundColor:
                            SeniorColors.manchesterColorRed100,
                        selectedFontColor: SeniorColors.manchesterColorRed500,
                        selectedValue: 'Não atende',
                        onSelect: (value) {
                          _onSelect(value);
                        },
                      ),
                    ),
                  ],
                ),
              ],
            ),
          ),
          Panel(
            title: 'Resultado',
            child: Column(
              children: [
                SeniorText.label(
                  _resultado,
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}
