// ignore_for_file: deprecated_member_use_from_same_package

import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_colorful_header_structure_style.dart';
import '../../repositories/theme_repository.dart';

@Deprecated('Use SeniorBackdrop instead')
class SeniorColorfulHeaderStructure extends StatefulWidget {
  /// Create a view structure component with header (app bar) and body according to the design system.
  /// The [body] and [title] parameters are required.
  const SeniorColorfulHeaderStructure({
    Key? key,
    this.actions,
    required this.body,
    this.hasTopPadding = true,
    this.hideLeading = false,
    this.leading,
    this.onTapBack,
    this.style,
    required this.title,
  }) : super(
          key: key,
        );

  /// List of actions in the header.
  final List<Widget>? actions;

  /// The content that will be displayed in the component body.
  final Widget body;

  /// Defines whether to have padding on top of the component's body.
  final bool hasTopPadding;

  /// Defines whether the leading will be hidden.
  final bool hideLeading;

  /// The leading of the component.
  final Widget? leading;

  /// Callback function executed when the option to return (leading) is activated.
  final Function()? onTapBack;

  /// The component's style definitions.
  /// Allows you to configure:
  /// [SeniorColorfulHeaderStructureStyle.bodyColor] the color for the component's body.
  /// [SeniorColorfulHeaderStructureStyle.headerColors] the colors for the title bar gradient.
  final SeniorColorfulHeaderStructureStyle? style;

  /// O título do header.
  final Widget title;

  @override
  State<SeniorColorfulHeaderStructure> createState() => _SeniorColorfulHeaderStructureState();
}

class _SeniorColorfulHeaderStructureState extends State<SeniorColorfulHeaderStructure> {
  final _borderRadius = const BorderRadius.only(
    topLeft: const Radius.circular(
      SeniorRadius.huge,
    ),
    topRight: Radius.circular(
      SeniorRadius.huge,
    ),
  );

  @override
  Widget build(BuildContext context) {
    final theme = Provider.of<ThemeRepository>(context).theme;

    return Container(
      decoration: BoxDecoration(
        gradient: LinearGradient(
          colors: widget.style?.headerColors ??
              theme.colorfulHeaderStructureTheme?.style?.headerColors ??
              SeniorColors.primaryGradientColors,
        ),
      ),
      child: Column(
        children: [
          AppBar(
            leadingWidth: widget.hideLeading ? 0 : null,
            leading: widget.hideLeading
                ? const SizedBox.shrink()
                : IconButton(
                    icon: const Icon(FontAwesomeIcons.angleLeft),
                    onPressed: widget.onTapBack ??
                        () {
                          Navigator.pop(context);
                        },
                  ),
            elevation: 0,
            backgroundColor: Colors.transparent,
            actions: widget.actions,
            title: widget.title,
            centerTitle: false,
          ),
          Expanded(
            child: Container(
              padding: EdgeInsets.only(
                top: widget.hasTopPadding ? SeniorRadius.huge : 0,
              ),
              decoration: BoxDecoration(
                borderRadius: _borderRadius,
                color: widget.style?.bodyColor ??
                    theme.colorfulHeaderStructureTheme?.style?.bodyColor ??
                    SeniorColors.pureWhite,
              ),
              child: ClipRRect(
                borderRadius: _borderRadius,
                child: widget.body,
              ),
            ),
          )
        ],
      ),
    );
  }
}
